package com.digio.digio_plugin

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import com.digio.`in`.esign2sdk.*


class DemoDigioChannel  : AppCompatActivity() , DigioResponseListener {

    companion object {
        private const val ERROR_UNKNOWN = 8988
        private const val ERROR_NO_DOCUMENT_ID = 9890

        private fun getEnvironment(env: String): DigioEnvironment? {
            return when (env) {
                "production" -> DigioEnvironment.PRODUCTION
                "sandbox" -> DigioEnvironment.SANDBOX
                "stage" -> DigioEnvironment.STAGE
                else -> null
            }
        }

        private fun getServiceMode(env: String): DigioServiceMode? {
            return when (env) {
                "otp" -> DigioServiceMode.OTP
                "fp" -> DigioServiceMode.FP
                "iris" -> DigioServiceMode.IRIS
                else -> null
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)


        val documentId = intent.getStringExtra("id").toString()
        val identifier = intent.getStringExtra("identifier").toString()
        val tokenId = intent.getStringExtra("tokenId").toString()
        val environment = intent.getStringExtra("environment")
        val serviceMode = intent.getStringExtra("service_mode")
        val logo = intent.getStringExtra("logo")

        startDigio(documentId, identifier, tokenId, environment, serviceMode, logo)
    }

    private fun startDigio(
        id: String,
        identifier: String,
        tokenId: String,
        environment: String?,
        serviceMode: String?,
        logo: String?
    ) {
        val digio = Digio()
        val digioConfig = DigioConfig()

//        todo use of tokenId

        if (environment != null)
            digioConfig.environment = getEnvironment(environment)
        if (serviceMode != null)
            digioConfig.serviceMode = getServiceMode(serviceMode)
        if (logo != null)
            digioConfig.logo = logo

        try {
            digio.init(this@DemoDigioChannel, digioConfig)
            digio.esign(id, identifier, this) //this refers DigioResponseListener
        } catch (e: java.lang.Exception) {
            e.printStackTrace()
            responseErrorToFlutter(ERROR_UNKNOWN, null, e.message)
        }
    }


    private fun responseSuccessToFlutter(documentId: String, message: String?) {
        val resultIntent = Intent()
        resultIntent.putExtra("documentId", documentId)
        resultIntent.putExtra("message", message)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }
    private fun responseErrorToFlutter(code: Int, documentId: String?, message: String?) {
        val resultIntent = Intent()
        resultIntent.putExtra("code", code)
        resultIntent.putExtra("documentId", documentId)
        resultIntent.putExtra("message", message)
        setResult(Activity.RESULT_CANCELED, resultIntent)
        finish()
    }

    override fun onSigningSuccess(documentId: String?, message: String?) {
        documentId ?: return responseErrorToFlutter(ERROR_NO_DOCUMENT_ID, null, message)
        responseSuccessToFlutter(documentId, message)
    }

    override fun onSigningFailure(documentId: String?, code: Int, response: String?) {
        responseErrorToFlutter(code, documentId, response)
    }
}
