package com.digio.digio_plugin

import android.app.Activity
import android.content.Context
import android.content.Intent
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

class DigioPlugin : Activity(), FlutterPlugin, MethodCallHandler, ActivityAware {

    companion object {
        private const val CHANNEL_NAME = "digio_plugin"
        private const val METHOD_START = "start_digio"
        private const val DIGIO_REQUEST_CODE = 101
    }

    private lateinit var channel: MethodChannel
    private lateinit var conext: Context
    private lateinit var activity: Activity

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, CHANNEL_NAME)
        conext = flutterPluginBinding.applicationContext
        channel.setMethodCallHandler(this)

    }

    private var response: Result? = null


    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "getPlatformVersion" -> {
                result.success("Android ${android.os.Build.VERSION.RELEASE}")
            }
            METHOD_START -> {
                response = result //Assign result in global variable
                val docId = call.argument<String>("doc_id").toString()
                val identifier = call.argument<String>("identifier").toString()
                val tokenId = call.argument<String>("tokenId").toString()
                val environment = call.argument<String>("environment")
                val serviceMode = call.argument<String>("service_mode")
                val logo = call.argument<String>("logo")
                callNativeClass(docId, identifier, tokenId, environment, serviceMode, logo)
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    private fun callNativeClass(
        id: String,
        identifier: String,
        tokenId: String,
        environment: String?,
        serviceMode: String?,
        logo: String?
    ) {
        val intent = Intent(conext, DemoDigioChannel::class.java)
        intent.putExtra("id", id)
        intent.putExtra("identifier", identifier)
        intent.putExtra("tokenId", tokenId)
        intent.putExtra("environment", environment)
        intent.putExtra("service_mode", serviceMode)
        intent.putExtra("logo", logo)
        activity.startActivityForResult(
            intent,
            DIGIO_REQUEST_CODE
        ) // pass any request code to check in
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        if (requestCode != DIGIO_REQUEST_CODE) return
        if (data == null) return
        val docId = data.getStringExtra("documentId")
        val responseMessage = data.getStringExtra("message")
        if (resultCode == RESULT_OK) {
            response?.success(mapOf("doc_id" to docId, "response_message" to responseMessage))
        } else if (resultCode == RESULT_CANCELED) {
            val code = data.getIntExtra("code", 0).toString()
            response?.error(code, responseMessage, docId)
        }

        super.onActivityResult(requestCode, resultCode, data)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity;
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }
}
