import 'dart:async';

import 'package:flutter/services.dart';

enum DigioEnvironment{
  production,
  sandbox,
  stage
}

enum DigioServiceMode {
  otp,
  fp,
  iris
}

class DigioPlugin {
  final platform = const MethodChannel('digio_plugin');
  static const _methodStart = 'start_digio';

  final String docId;
  final String identifier;
  final String tokenId;
  final DigioEnvironment? environment;
  final DigioServiceMode? serviceMode;
  final String? logo;
  final void Function(String docId, String message) onSuccess;
  final void Function(int code, String message) onError;

  DigioPlugin(
      {required this.docId,
      required this.identifier,
      required this.tokenId,
      this.environment,
      this.serviceMode,
      this.logo,
      required this.onSuccess,
      required this.onError});

  // "KID211022183925773KR2CKYP9ALACTT"
  // akash@digio.in
  // GWT2110221839258012CG3YM58ZTE3MN
  Future<void> launch() async {
    try {
      // Create map to pass required data from flutter to native
      Map<String, dynamic> args = <String, dynamic>{};
      // Assign key and value as per your requirement
      args.putIfAbsent("doc_id", () => docId);
      args.putIfAbsent("identifier", () => identifier);
      args.putIfAbsent("tokenId", () => tokenId);
      args.putIfAbsent("environment", () => environment?.name);
      args.putIfAbsent("service_mode", () => serviceMode?.name);
      args.putIfAbsent("logo", () => logo);
      final Map<String, String> result = await platform.invokeMethod(_methodStart, args);
      onSuccess(result['doc_id'] ?? '', result['response_message'] ?? '');
    } on PlatformException catch (e) {
      onError(int.tryParse(e.code) ?? 0, e.message ?? '');
    }
  }
}
